;; Generated package description from pulsar.el  -*- no-byte-compile: t -*-
(define-package "pulsar" "0.3.1" "Pulse highlight on demand or after select functions" '((emacs "27.1")) :commit "86a7c429c6878287c068106b318889824cad3210" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "pulse" "highlight") :url "https://git.sr.ht/~protesilaos/pulsar")
